"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mergeQueries = exports.mapQuery = void 0;
const compute_1 = require("./compute");
/**
 * Creates a new `Query` which maps a source value by the provided mapping
 * function.
 *
 * @param query source query
 * @param mapper value mapper
 */
function mapQuery(query, mapper) {
    return (0, compute_1.compute)((get) => mapper(get(query)), [query]);
}
exports.mapQuery = mapQuery;
/**
 * Creates a new `Query` which takes the latest values from source queries
 * and merges them into a single value.
 *
 * @param queries source queries
 * @param merger value merger
 */
function mergeQueries(queries, merger) {
    return (0, compute_1.compute)((get) => {
        const values = queries.map((query) => get(query));
        return merger(...values);
    }, queries);
}
exports.mergeQueries = mergeQueries;
//# sourceMappingURL=queryMappers.js.map