import { createStore } from './store';
/**
 * Creates a deferred or transformed view of the store.
 */
export function pipeStore(store, operator) {
    let subscription;
    const clone = createStore(store.get(), {
        internal: true,
        onDestroy: () => {
            if (subscription) {
                subscription.unsubscribe();
                subscription = undefined;
            }
        },
    });
    subscription = store.value$.pipe(operator).subscribe({
        next: (state) => {
            clone.set(state);
        },
        complete: () => {
            clone.destroy();
        },
    });
    return clone;
}
//# sourceMappingURL=pipeStore.js.map