import { compute } from './compute';
/**
 * Creates a new `Query` which maps a source value by the provided mapping
 * function.
 *
 * @param query source query
 * @param mapper value mapper
 */
export function mapQuery(query, mapper) {
    return compute((get) => mapper(get(query)), [query]);
}
/**
 * Creates a new `Query` which takes the latest values from source queries
 * and merges them into a single value.
 *
 * @param queries source queries
 * @param merger value merger
 */
export function mergeQueries(queries, merger) {
    return compute((get) => {
        const values = queries.map((query) => get(query));
        return merger(...values);
    }, queries);
}
//# sourceMappingURL=queryMappers.js.map